@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
+from trytond.pyson import If, Equal, Eval, Not, In, Get
 
 
 class OrderPoint(ModelSQL, ModelView):
@@ -15,42 +16,51 @@ class OrderPoint(ModelSQL, ModelView):
 
     product = fields.Many2One(
         'product.product', 'Product', required=True, select=1,
-        domain=[('type', '=', 'stockable'), "('purchasable', 'in', " \
-                "type == 'purchase' and [True] or [True, False])"],
+        domain=[
+            ('type', '=', 'stockable'),
+            ('purchasable', 'in', If(Equal(Eval('type'), 'purchase'),
+                [True], [True, False])),
+        ],
         on_change=['product'])
     warehouse_location = fields.Many2One(
         'stock.location', 'Warehouse Location', select=1,
         domain=[('type', '=', 'warehouse')],
-        states={'invisible': "type != 'purchase'",
-                'required': "type == 'purchase'"},)
+        states={
+            'invisible': Not(Equal(Eval('type'), 'purchase')),
+            'required': Equal(Eval('type'), 'purchase'),
+        })
     storage_location = fields.Many2One(
         'stock.location', 'Storage Location', select=1,
         domain=[('type', '=', 'storage')],
-        states={'invisible': "type != 'internal'",
-                'required': "type == 'internal'"},)
-    location = fields.Function(
-        'get_location', type='many2one', relation='stock.location',
-        fnct_search='search_location', string='Location')
+        states={
+            'invisible': Not(Equal(Eval('type'), 'internal')),
+            'required': Equal(Eval('type'), 'internal'),
+        })
+    location = fields.Function(fields.Many2One('stock.location', 'Location'),
+            'get_location', searcher='search_location')
     provisioning_location = fields.Many2One(
         'stock.location', 'Provisioning Location',
         domain=[('type', '=', 'storage')],
-        states={'invisible': "type != 'internal'",
-                'required': "type == 'internal'"},)
+        states={
+            'invisible': Not(Equal(Eval('type'), 'internal')),
+            'required': Equal(Eval('type'), 'internal'),
+        })
     type = fields.Selection(
         [('internal', 'Internal'),
          ('purchase', 'Purchase')],
         'Type', select=1, required=True)
     min_quantity = fields.Float('Minimal Quantity', required=True,
-            digits="(16, unit_digits)", depends=['unit_digits'])
+            digits=(16, Eval('unit_digits', 2)), depends=['unit_digits'])
     max_quantity = fields.Float('Maximal Quantity', required=True,
-            digits="(16, unit_digits)", depends=['unit_digits'])
+            digits=(16, Eval('unit_digits', 2)), depends=['unit_digits'])
     company = fields.Many2One('company.company', 'Company', required=True,
-            domain=["('id', 'company' in context and '=' or '!=', " \
-                    "context.get('company', 0))"])
-    unit = fields.Function('get_unit', type='many2one', relation='product.uom',
-            string='Unit')
-    unit_digits = fields.Function('get_unit_digits', type='integer',
-            string='Unit Digits')
+            domain=[
+                ('id', If(In('company', Eval('context', {})), '=', '!='),
+                    Get(Eval('context', {}), 'company', 0)),
+            ])
+    unit = fields.Function(fields.Many2One('product.uom', 'Unit'), 'get_unit')
+    unit_digits = fields.Function(fields.Integer('Unit Digits'),
+            'get_unit_digits')
 
     def __init__(self):
         super(OrderPoint, self).__init__()
@@ -72,7 +82,7 @@ class OrderPoint(ModelSQL, ModelView):
     def default_type(self, cursor, user, context=None):
         return "purchase"
 
-    def on_change_product(self, cursor, user, ids, vals, context=None):
+    def on_change_product(self, cursor, user, vals, context=None):
         product_obj = self.pool.get('product.product')
         res = {
             'unit': False,
@@ -87,13 +97,13 @@ class OrderPoint(ModelSQL, ModelView):
             res['unit_digits'] = product.default_uom.digits
         return res
 
-    def get_unit(self, cursor, user, ids, name, arg, context=None):
+    def get_unit(self, cursor, user, ids, name, context=None):
         res = {}
         for order in self.browse(cursor, user, ids, context=context):
             res[order.id] = order.product.default_uom.id
         return res
 
-    def get_unit_digits(self, cursor, user, ids, name, arg, context=None):
+    def get_unit_digits(self, cursor, user, ids, name, context=None):
         res = {}
         for order in self.browse(cursor, user, ids, context=context):
             res[order.id] = order.product.default_uom.digits
@@ -147,7 +157,7 @@ class OrderPoint(ModelSQL, ModelView):
         ids = self.search(cursor, user, query)
         return not bool(ids)
 
-    def get_rec_name(self, cursor, user, ids, name, arg, context=None):
+    def get_rec_name(self, cursor, user, ids, name, context=None):
         if not ids:
             return {}
         if isinstance(ids, (int, long)):
@@ -157,18 +167,15 @@ class OrderPoint(ModelSQL, ModelView):
             res[op.id] = "%s@%s" % (op.product.name, op.location.name)
         return res
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            names = args[i][2].split('@', 1)
-            args2.append(('product.template.name', args[i][1], names[0]))
-            if len(names) != 1 and names[1]:
-                args2.append(('location', args[i][1], names[1]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        res = []
+        names = clause[2].split('@', 1)
+        res.append(('product.template.name', clause[1], names[0]))
+        if len(names) != 1 and names[1]:
+            res.append(('location', clause[1], names[1]))
+        return res
 
-    def get_location(self, cursor, user, ids, name, args, context=None):
+    def get_location(self, cursor, user, ids, name, context=None):
         location_obj = self.pool.get('stock.location')
         res = {}
         for op in self.browse(cursor, user, ids, context=context):
@@ -190,7 +197,6 @@ class OrderPoint(ModelSQL, ModelView):
         return [('id', 'in', ids)]
 
     def default_company(self, cursor, user, context=None):
-        company_obj = self.pool.get('company.company')
         if context is None:
             context = {}
         if context.get('company'):
