@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
+from trytond.pyson import If, In, Eval, Get
 import datetime
 
 
@@ -26,22 +27,21 @@ class PurchaseRequest(ModelSQL, ModelView):
         domain=[('type', '=', 'warehouse')], readonly=True)
     purchase_line = fields.Many2One(
         'purchase.line', 'Purchase Line',readonly=True)
-    purchase = fields.Function(
-        'get_purchase', type='many2one', relation='purchase.purchase',
-        string='Purchase')
+    purchase = fields.Function(fields.Many2One('purchase.purchase',
+        'Purchase'), 'get_purchase')
     company = fields.Many2One('company.company', 'Company', required=True,
             readonly=True, domain=[
-                "('id', 'company' in context and '=' or '!=', " \
-                        "context.get('company', 0))"])
+                ('id', If(In('company', Eval('context', {})), '=', '!='),
+                    Get(Eval('context', {}), 'company', 0)),
+            ])
     origin = fields.Reference('Origin', selection='origin_get', readonly=True,
             required=True)
-    state = fields.Function(
-        'get_state', type='selection',
-        selection=[("purchased", "Purchased"),
-                   ("done", "Done"),
-                   ("draft", "Draft"),
-                   ("cancel", "Cancel")],
-        string="State", readonly=True)
+    state = fields.Function(fields.Selection([
+        ('purchased', 'Purchased'),
+        ('done', 'Done'),
+        ('draft', 'Draft'),
+        ('cancel', 'Cancel'),
+        ], 'State'), 'get_state')
 
     def __init__(self):
         super(PurchaseRequest, self).__init__()
@@ -50,7 +50,7 @@ class PurchaseRequest(ModelSQL, ModelView):
             'create_request': 'Purchase requests are only created by the system.',
             })
 
-    def get_rec_name(self, cursor, user, ids, name, arg, context=None):
+    def get_rec_name(self, cursor, user, ids, name, context=None):
         if isinstance(ids, (int, long)):
             ids = [ids]
         res = {}
@@ -58,26 +58,22 @@ class PurchaseRequest(ModelSQL, ModelView):
             res[pr.id] = "%s@%s" % (pr.product.name, pr.warehouse.name)
         return res
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            names = args[i][2].split('@', 1)
-            args2.append(('product.template.name', args[i][1], names[0]))
-            if len(names) != 1 and names[1]:
-                args2.append(('warehouse', args[i][1], names[1]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        res = []
+        names = clause[2].split('@', 1)
+        res.append(('product.template.name', clause[1], names[0]))
+        if len(names) != 1 and names[1]:
+            res.append(('warehouse', clause[1], names[1]))
+        return res
 
     def default_company(self, cursor, user, context=None):
-        company_obj = self.pool.get('company.company')
         if context is None:
             context = {}
         if context.get('company'):
             return context['company']
         return False
 
-    def get_purchase(self, cursor, user, ids, name, args, context=None):
+    def get_purchase(self, cursor, user, ids, name, context=None):
         res = {}
 
         requests = self.browse(cursor, user, ids, context=context)
@@ -88,7 +84,7 @@ class PurchaseRequest(ModelSQL, ModelView):
                 res[request.id] = False
         return res
 
-    def get_state(self, cursor, user, ids, name, args, context=None):
+    def get_state(self, cursor, user, ids, name, context=None):
         res = {}.fromkeys(ids, 'draft')
         for request in self.browse(cursor, user, ids, context=context):
             if request.purchase_line:
